@@ -26,14 +26,13 @@
 #include <glib/gi18n.h>
 #include <libupower-glib/upower.h>
 
-#include "egg-debug.h"
-
 #include "gpm-common.h"
 #include "gpm-upower.h"
 #include "gpm-marshal.h"
 #include "gpm-engine.h"
 #include "gpm-stock-icons.h"
 #include "gpm-phone.h"
+#include "gpm-debug.h"
 
 static void     gpm_engine_finalize   (GObject	  *object);
 
@@ -148,7 +147,7 @@ gpm_engine_get_warning_time (GpmEngine *engine, UpDevice *device)
 
 	/* this is probably an error condition */
 	if (time_to_empty == 0) {
-		egg_debug ("time zero, falling back to percentage for %s", up_device_kind_to_string (kind));
+		g_debug ("time zero, falling back to percentage for %s", up_device_kind_to_string (kind));
 		return gpm_engine_get_warning_percentage (engine, device);
 	}
 
@@ -270,7 +269,7 @@ gpm_engine_get_summary (GpmEngine *engine)
 	/* remove the last \n */
 	g_string_truncate (tooltip, tooltip->len-1);
 
-	egg_debug ("tooltip: %s", tooltip->str);
+	g_debug ("tooltip: %s", tooltip->str);
 
 	return g_string_free (tooltip, FALSE);
 }
@@ -339,7 +338,7 @@ gpm_engine_get_icon (GpmEngine *engine)
 
 	/* policy */
 	if (engine->priv->icon_policy == GPM_ICON_POLICY_NEVER) {
-		egg_debug ("no icon allowed, so no icon will be displayed.");
+		g_debug ("no icon allowed, so no icon will be displayed.");
 		return NULL;
 	}
 
@@ -359,7 +358,7 @@ gpm_engine_get_icon (GpmEngine *engine)
 
 	/* policy */
 	if (engine->priv->icon_policy == GPM_ICON_POLICY_CRITICAL) {
-		egg_debug ("no devices critical, so no icon will be displayed.");
+		g_debug ("no devices critical, so no icon will be displayed.");
 		return NULL;
 	}
 
@@ -379,7 +378,7 @@ gpm_engine_get_icon (GpmEngine *engine)
 
 	/* policy */
 	if (engine->priv->icon_policy == GPM_ICON_POLICY_LOW) {
-		egg_debug ("no devices low, so no icon will be displayed.");
+		g_debug ("no devices low, so no icon will be displayed.");
 		return NULL;
 	}
 
@@ -393,7 +392,7 @@ gpm_engine_get_icon (GpmEngine *engine)
 
 	/* policy */
 	if (engine->priv->icon_policy == GPM_ICON_POLICY_CHARGE) {
-		egg_debug ("no devices (dis)charging, so no icon will be displayed.");
+		g_debug ("no devices (dis)charging, so no icon will be displayed.");
 		return NULL;
 	}
 
@@ -407,7 +406,7 @@ gpm_engine_get_icon (GpmEngine *engine)
 
 	/* policy */
 	if (engine->priv->icon_policy == GPM_ICON_POLICY_PRESENT) {
-		egg_debug ("no devices present, so no icon will be displayed.");
+		g_debug ("no devices present, so no icon will be displayed.");
 		return NULL;
 	}
 
@@ -433,7 +432,7 @@ gpm_engine_recalculate_state_icon (GpmEngine *engine)
 		if (engine->priv->previous_icon == NULL)
 			return FALSE;
 		/* icon before, now none */
-		egg_debug ("** EMIT: icon-changed: none");
+		g_debug ("** EMIT: icon-changed: none");
 		g_signal_emit (engine, signals [ICON_CHANGED], 0, NULL);
 
 		g_object_unref (engine->priv->previous_icon);
@@ -456,7 +455,7 @@ gpm_engine_recalculate_state_icon (GpmEngine *engine)
 		return TRUE;
 	}
 
-	egg_debug ("no change");
+	g_debug ("no change");
 	/* nothing to do */
 	g_object_unref (icon);
 	return FALSE;
@@ -473,7 +472,7 @@ gpm_engine_recalculate_state_summary (GpmEngine *engine)
 	summary = gpm_engine_get_summary (engine);
 	if (engine->priv->previous_summary == NULL) {
 		engine->priv->previous_summary = summary;
-		egg_debug ("** EMIT: summary-changed(1): %s", summary);
+		g_debug ("** EMIT: summary-changed(1): %s", summary);
 		g_signal_emit (engine, signals [SUMMARY_CHANGED], 0, summary);
 		return TRUE;
 	}	
@@ -481,11 +480,11 @@ gpm_engine_recalculate_state_summary (GpmEngine *engine)
 	if (strcmp (engine->priv->previous_summary, summary) != 0) {
 		g_free (engine->priv->previous_summary);
 		engine->priv->previous_summary = summary;
-		egg_debug ("** EMIT: summary-changed(2): %s", summary);
+		g_debug ("** EMIT: summary-changed(2): %s", summary);
 		g_signal_emit (engine, signals [SUMMARY_CHANGED], 0, summary);
 		return TRUE;
 	}
-	egg_debug ("no change");
+	g_debug ("no change");
 	/* nothing to do */
 	g_free (summary);
 	return FALSE;
@@ -513,17 +512,13 @@ gpm_engine_recalculate_state (GpmEngine *engine)
 static void
 gpm_engine_settings_key_changed_cb (GSettings *settings, const gchar *key, GpmEngine *engine)
 {
-	gchar *icon_policy;
-
 	if (g_strcmp0 (key, GPM_SETTINGS_USE_TIME_POLICY) == 0) {
 		engine->priv->use_time_primary = g_settings_get_boolean (settings, key);
 
 	} else if (g_strcmp0 (key, GPM_SETTINGS_ICON_POLICY) == 0) {
 
 		/* do we want to display the icon in the tray */
-		icon_policy = g_settings_get_string (settings, key);
-		engine->priv->icon_policy = gpm_icon_policy_from_string (icon_policy);
-		g_free (icon_policy);
+		engine->priv->icon_policy = g_settings_get_enum (settings, key);
 
 		/* perhaps change icon */
 		gpm_engine_recalculate_state_icon (engine);
@@ -561,7 +556,7 @@ gpm_engine_device_check_capacity (GpmEngine *engine, UpDevice *device)
 	/* only emit this if specified in the settings */
 	ret = g_settings_get_boolean (engine->priv->settings, GPM_SETTINGS_NOTIFY_LOW_CAPACITY);
 	if (ret) {
-		egg_debug ("** EMIT: low-capacity");
+		g_debug ("** EMIT: low-capacity");
 		g_signal_emit (engine, signals [LOW_CAPACITY], 0, device);
 	}
 	return TRUE;
@@ -598,7 +593,7 @@ gpm_engine_get_composite_device (GpmEngine *engine, UpDevice *original_device)
 
 	/* just use the original device if only one primary battery */
 	if (battery_devices <= 1) {
-		egg_debug ("using original device as only one primary battery");
+		g_debug ("using original device as only one primary battery");
 		device = original_device;
 		goto out;
 	}
@@ -617,10 +612,10 @@ static UpDevice *
 gpm_engine_update_composite_device (GpmEngine *engine, UpDevice *original_device)
 {
 	guint i;
-	gdouble percentage;
-	gdouble energy;
-	gdouble energy_full;
-	gdouble energy_rate;
+	gdouble percentage = 0.0;
+	gdouble energy = 0.0;
+	gdouble energy_full = 0.0;
+	gdouble energy_rate = 0.0;
 	gdouble energy_total = 0.0;
 	gdouble energy_full_total = 0.0;
 	gdouble energy_rate_total = 0.0;
@@ -639,7 +634,7 @@ gpm_engine_update_composite_device (GpmEngine *engine, UpDevice *original_device
 	gchar *text;
 
 	/* are we printing to console? */
-	debug = egg_debug_enabled ();
+	debug = gpm_debug_is_verbose ();
 
 	/* get the type of the original device */
 	g_object_get (original_device,
@@ -662,7 +657,7 @@ gpm_engine_update_composite_device (GpmEngine *engine, UpDevice *original_device
 
 		if (debug) {
 			text = up_device_to_text (device);
-			egg_debug ("printing device %i:\n%s", i, text);
+			g_debug ("printing device %i:\n%s", i, text);
 			g_free (text);
 		}
 
@@ -683,7 +678,7 @@ gpm_engine_update_composite_device (GpmEngine *engine, UpDevice *original_device
 
 	/* just use the original device if only one primary battery */
 	if (battery_devices == 1) {
-		egg_debug ("using original device as only one primary battery");
+		g_debug ("using original device as only one primary battery");
 		device = original_device;
 		goto out;
 	}
@@ -712,7 +707,7 @@ gpm_engine_update_composite_device (GpmEngine *engine, UpDevice *original_device
 	/* okay, we can use the composite device */
 	device = engine->priv->battery_composite;
 
-	egg_debug ("printing composite device");
+	g_debug ("printing composite device");
 	g_object_set (device,
 		      "energy", energy,
 		      "energy-full", energy_full,
@@ -724,7 +719,7 @@ gpm_engine_update_composite_device (GpmEngine *engine, UpDevice *original_device
 		      NULL);
 	if (debug) {
 		text = up_device_to_text (device);
-		egg_debug ("composite:\n%s", text);
+		g_debug ("composite:\n%s", text);
 		g_free (text);
 	}
 
@@ -760,11 +755,11 @@ gpm_engine_device_add (GpmEngine *engine, UpDevice *device)
 		      NULL);
 
 	/* add old state for transitions */
-	egg_debug ("adding %s with state %s", up_device_get_object_path (device), up_device_state_to_string (state));
+	g_debug ("adding %s with state %s", up_device_get_object_path (device), up_device_state_to_string (state));
 	g_object_set_data (G_OBJECT(device), "engine-state-old", GUINT_TO_POINTER(state));
 
 	if (kind == UP_DEVICE_KIND_BATTERY) {
-		egg_debug ("updating because we added a device");
+		g_debug ("updating because we added a device");
 		composite = gpm_engine_update_composite_device (engine, device);
 
 		/* get the same values for the composite device */
@@ -803,7 +798,7 @@ gpm_engine_check_recall (GpmEngine *engine, UpDevice *device)
 		goto out;
 
 	/* emit signal for manager */
-	egg_debug ("** EMIT: perhaps-recall");
+	g_debug ("** EMIT: perhaps-recall");
 	g_signal_emit (engine, signals [PERHAPS_RECALL], 0, device, recall_vendor, recall_url);
 out:
 	g_free (recall_vendor);
@@ -829,7 +824,7 @@ gpm_engine_coldplug_idle_cb (GpmEngine *engine)
 	/* get devices from UPower */
 	ret = up_client_enumerate_devices_sync (engine->priv->client, NULL, &error);
 	if (!ret) {
-		egg_error ("failed to get device list: %s", error->message);
+		g_error ("failed to get device list: %s", error->message);
 		g_error_free (error);
 		goto out;
 	}
@@ -879,7 +874,6 @@ gpm_engine_device_removed_cb (UpClient *client, UpDevice *device, GpmEngine *eng
 	gpm_engine_recalculate_state (engine);
 }
 
-
 /**
  * gpm_engine_device_changed_cb:
  **/
@@ -899,7 +893,7 @@ gpm_engine_device_changed_cb (UpClient *client, UpDevice *device, GpmEngine *eng
 
 	/* if battery then use composite device to cope with multiple batteries */
 	if (kind == UP_DEVICE_KIND_BATTERY) {
-		egg_debug ("updating because %s changed", up_device_get_object_path (device));
+		g_debug ("updating because %s changed", up_device_get_object_path (device));
 		device = gpm_engine_update_composite_device (engine, device);
 	}
 
@@ -908,16 +902,16 @@ gpm_engine_device_changed_cb (UpClient *client, UpDevice *device, GpmEngine *eng
 		      "state", &state,
 		      NULL);
 
-	egg_debug ("%s state is now %s", up_device_get_object_path (device), up_device_state_to_string (state));
+	g_debug ("%s state is now %s", up_device_get_object_path (device), up_device_state_to_string (state));
 
 	/* see if any interesting state changes have happened */
 	state_old = GPOINTER_TO_INT(g_object_get_data (G_OBJECT(device), "engine-state-old"));
 	if (state_old != state) {
 		if (state == UP_DEVICE_STATE_DISCHARGING) {
-			egg_debug ("** EMIT: discharging");
+			g_debug ("** EMIT: discharging");
 			g_signal_emit (engine, signals [DISCHARGING], 0, device);
 		} else if (state == UP_DEVICE_STATE_FULLY_CHARGED) {
-			egg_debug ("** EMIT: fully charged");
+			g_debug ("** EMIT: fully charged");
 			g_signal_emit (engine, signals [FULLY_CHARGED], 0, device);
 		}
 
@@ -930,13 +924,13 @@ gpm_engine_device_changed_cb (UpClient *client, UpDevice *device, GpmEngine *eng
 	warning = gpm_engine_get_warning (engine, device);
 	if (warning != warning_old) {
 		if (warning == GPM_ENGINE_WARNING_LOW) {
-			egg_debug ("** EMIT: charge-low");
+			g_debug ("** EMIT: charge-low");
 			g_signal_emit (engine, signals [CHARGE_LOW], 0, device);
 		} else if (warning == GPM_ENGINE_WARNING_CRITICAL) {
-			egg_debug ("** EMIT: charge-critical");
+			g_debug ("** EMIT: charge-critical");
 			g_signal_emit (engine, signals [CHARGE_CRITICAL], 0, device);
 		} else if (warning == GPM_ENGINE_WARNING_ACTION) {
-			egg_debug ("** EMIT: charge-action");
+			g_debug ("** EMIT: charge-action");
 			g_signal_emit (engine, signals [CHARGE_ACTION], 0, device);
 		}
 		/* save new state */
@@ -1010,7 +1004,7 @@ phone_device_added_cb (GpmPhone *phone, guint idx, GpmEngine *engine)
 	UpDevice *device;
 	device = up_device_new ();
 
-	egg_debug ("phone added %i", idx);
+	g_debug ("phone added %i", idx);
 
 	/* get device properties */
 	g_object_set (device,
@@ -1036,7 +1030,7 @@ phone_device_removed_cb (GpmPhone *phone, guint idx, GpmEngine *engine)
 	UpDevice *device;
 	UpDeviceKind kind;
 
-	egg_debug ("phone removed %i", idx);
+	g_debug ("phone removed %i", idx);
 
 	for (i=0; i<engine->priv->array->len; i++) {
 		device = g_ptr_array_index (engine->priv->array, i);
@@ -1069,7 +1063,7 @@ phone_device_refresh_cb (GpmPhone *phone, guint idx, GpmEngine *engine)
 	gboolean is_present;
 	gdouble percentage;
 
-	egg_debug ("phone refresh %i", idx);
+	g_debug ("phone refresh %i", idx);
 
 	for (i=0; i<engine->priv->array->len; i++) {
 		device = g_ptr_array_index (engine->priv->array, i);
@@ -1101,7 +1095,6 @@ phone_device_refresh_cb (GpmPhone *phone, guint idx, GpmEngine *engine)
 static void
 gpm_engine_init (GpmEngine *engine)
 {
-	gchar *icon_policy;
 	guint idle_id;
 
 	engine->priv = GPM_ENGINE_GET_PRIVATE (engine);
@@ -1141,9 +1134,7 @@ gpm_engine_init (GpmEngine *engine)
 	engine->priv->previous_summary = NULL;
 
 	/* do we want to display the icon in the tray */
-	icon_policy = g_settings_get_string (engine->priv->settings, GPM_SETTINGS_ICON_POLICY);
-	engine->priv->icon_policy = gpm_icon_policy_from_string (icon_policy);
-	g_free (icon_policy);
+	engine->priv->icon_policy = g_settings_get_enum (engine->priv->settings, GPM_SETTINGS_ICON_POLICY);
 
 	/* get percentage policy */
 	engine->priv->low_percentage = g_settings_get_int (engine->priv->settings, GPM_SETTINGS_PERCENTAGE_LOW);
@@ -1158,14 +1149,12 @@ gpm_engine_init (GpmEngine *engine)
 	/* we can disable this if the time remaining is inaccurate or just plain wrong */
 	engine->priv->use_time_primary = g_settings_get_boolean (engine->priv->settings, GPM_SETTINGS_USE_TIME_POLICY);
 	if (engine->priv->use_time_primary)
-		egg_debug ("Using per-time notification policy");
+		g_debug ("Using per-time notification policy");
 	else
-		egg_debug ("Using percentage notification policy");
+		g_debug ("Using percentage notification policy");
 
 	idle_id = g_idle_add ((GSourceFunc) gpm_engine_coldplug_idle_cb, engine);
-#if GLIB_CHECK_VERSION(2,25,8)
 	g_source_set_name_by_id (idle_id, "[GpmEngine] coldplug");
-#endif
 }
 
 /**
